@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-error-viewer-extension.c,v 1.13 2004/02/24 17:47:16 chpe Exp $
+ *  $Id: ephy-error-viewer-extension.c,v 1.19 2004/09/26 16:07:58 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,12 +43,16 @@
 
 #include <glib/gi18n-lib.h>
 
+#include <string.h>
+
 #ifdef HAVE_OPENSP
 #include "sgml-validator.h"
 #endif /* HAVE_OPENSP */
 
 #include "link-checker.h"
 
+#define WINDOW_DATA_KEY	"EphyErrorViewerExtWindowData"
+
 #define EPHY_ERROR_VIEWER_EXTENSION_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ERROR_VIEWER_EXTENSION, EphyErrorViewerExtensionPrivate))
 
 struct EphyErrorViewerExtensionPrivate
@@ -67,6 +71,12 @@ typedef struct
 	EphyWindow *window;
 } ErrorViewerCBData;
 
+typedef struct
+{
+	GtkActionGroup *action_group;
+	guint ui_id;
+} WindowData;
+
 static void ephy_error_viewer_extension_class_init	(EphyErrorViewerExtensionClass *klass);
 static void ephy_error_viewer_extension_iface_init	(EphyExtensionIface *iface);
 static void ephy_error_viewer_extension_init		(EphyErrorViewerExtension *extension);
@@ -273,9 +283,9 @@ update_actions (EphyWindow *window)
 	g_value_init (&sensitive, G_TYPE_BOOLEAN);
 	g_value_set_boolean (&sensitive, FALSE);
 
-	action1 = gtk_ui_manager_get_action (GTK_UI_MANAGER (window->ui_merge),
+	action1 = gtk_ui_manager_get_action (GTK_UI_MANAGER (ephy_window_get_ui_manager (window)),
 					     "/menubar/ToolsMenu/SgmlValidate");
-	action2 = gtk_ui_manager_get_action (GTK_UI_MANAGER (window->ui_merge),
+	action2 = gtk_ui_manager_get_action (GTK_UI_MANAGER (ephy_window_get_ui_manager (window)),
 					     "/menubar/ToolsMenu/CheckLinks");
 
 	tab = ephy_window_get_active_tab (window);
@@ -354,6 +364,15 @@ tab_removed_cb (GtkWidget *notebook,
 }
 #endif /* HAVE_OPENSP */
 
+static void
+free_window_data (WindowData *data)
+{
+	if (data) {
+		g_object_unref (data->action_group);
+		g_free (data);
+	}
+}
+
 static void
 impl_attach_window (EphyExtension *extension,
 		    EphyWindow *window)
@@ -365,26 +384,31 @@ impl_attach_window (EphyExtension *extension,
 	GtkWidget *notebook;
 #endif /* HAVE_OPENSP */
 	guint merge_id;
+	WindowData *data;
 
 	LOG ("EphyErrorViewerExtension attach_window")
 
-	cb_data = g_new0 (ErrorViewerCBData, 1);
+	cb_data = g_new (ErrorViewerCBData, 1);
 	cb_data->extension = EPHY_ERROR_VIEWER_EXTENSION (extension);
 	cb_data->window = window;
 
-	manager = GTK_UI_MANAGER (window->ui_merge);
+	data = g_new (WindowData, 1);
 
-	action_group = gtk_action_group_new ("EphyErrorViewerExtensionActions");
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 
+	data->action_group = action_group =
+		gtk_action_group_new ("EphyErrorViewerExtensionActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions_full (action_group, action_entries,
 					   n_action_entries, cb_data,
 					   free_error_viewer_cb_data);
 
 	gtk_ui_manager_insert_action_group (manager, action_group, 0);
-	g_object_unref (action_group);
 
-	merge_id = gtk_ui_manager_new_merge_id (manager);
+	data->ui_id = merge_id = gtk_ui_manager_new_merge_id (manager);
+
+	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY, data,
+				(GDestroyNotify) free_window_data);
 
 	gtk_ui_manager_add_ui (manager, merge_id, "/menubar/ToolsMenu",
 			       "ErrorViewerSep", NULL,
@@ -417,9 +441,26 @@ static void
 impl_detach_window (EphyExtension *extension,
 		    EphyWindow *window)
 {
+	GtkUIManager *manager;
+	WindowData *data;
 #ifdef HAVE_OPENSP
 	GtkWidget *notebook;
+	GList *tabs, *l;
+#endif /* HAVE_OPENSP */
 
+	/* Remove UI */
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
+
+	data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
+	g_return_if_fail (data != NULL);
+
+	gtk_ui_manager_remove_ui (manager, data->ui_id);
+	gtk_ui_manager_remove_action_group (manager, data->action_group);
+
+	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
+
+#ifdef HAVE_OPENSP
+	/* Remove notification signals for HTML/link checking */
 	notebook = ephy_window_get_notebook (window);
 
 	g_signal_handlers_disconnect_by_func
@@ -428,6 +469,13 @@ impl_detach_window (EphyExtension *extension,
 		(notebook, G_CALLBACK (tab_removed_cb), window);
 	g_signal_handlers_disconnect_by_func
 		(notebook, G_CALLBACK (switch_page_cb), window);
+
+	tabs = ephy_window_get_tabs (window);
+	for (l = tabs; l != NULL; l = l->next)
+	{
+		tab_removed_cb (notebook, (EphyTab *) l->data, window);
+	}
+	g_list_free (tabs);
 #endif /* HAVE_OPENSP */
 }
 
