@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: register-listener.cpp,v 1.3 2004/02/22 18:54:33 adamh Exp $
+ *  $Id: register-listener.cpp,v 1.4 2004/11/25 20:48:20 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,7 +26,7 @@
 
 #include "ErrorViewerConsoleListener.h"
 
-#include <nsIServiceManagerUtils.h>
+#include <nsIServiceManager.h>
 #include <nsIConsoleService.h>
 #include <nsCOMPtr.h>
 #include <nsXPCOM.h>
