@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-page-info-extension.c,v 1.8.2.1 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: ephy-page-info-extension.c,v 1.12 2004/10/28 00:27:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,6 +38,7 @@
 #include <glib/gi18n-lib.h>
 
 #define WINDOW_DATA_KEY "EphyPageInfoExtensionWindowData"
+#define MENU_PATH "/menubar/ToolsMenu"
 
 #define EPHY_PAGE_INFO_EXTENSION_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_PAGE_INFO_EXTENSION, EphyPageInfoExtensionPrivate))
 
@@ -168,8 +169,8 @@ update_action (EphyWindow *window,
 	GtkAction *action;
 	gboolean loading = TRUE;
 
-	action = gtk_ui_manager_get_action (GTK_UI_MANAGER (window->ui_merge),
-					    "/menubar/ToolsMenu/PageInfo");
+	action = gtk_ui_manager_get_action (GTK_UI_MANAGER (ephy_window_get_ui_manager (window)),
+					    MENU_PATH "/PageInfo");
 
 	g_object_get (G_OBJECT (tab), "load-status", &loading, NULL);
 	g_object_set (G_OBJECT (action), "sensitive", !loading, NULL);
@@ -239,7 +240,7 @@ impl_attach_window (EphyExtension *extension,
 
 	data = g_new (WindowData, 1);
 
-	manager = GTK_UI_MANAGER (window->ui_merge);
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 
 	data->action_group = action_group =
 		gtk_action_group_new ("EphyPageInfoExtensionActions");
@@ -254,13 +255,13 @@ impl_attach_window (EphyExtension *extension,
 	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY, data,
 				(GDestroyNotify) free_window_data);
 
-	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
+	gtk_ui_manager_add_ui (manager, ui_id, MENU_PATH,
 			       "PageInfoSep", NULL,
 			       GTK_UI_MANAGER_SEPARATOR, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
+	gtk_ui_manager_add_ui (manager, ui_id, MENU_PATH,
 			       "PageInfo", "PageInfo",
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
+	gtk_ui_manager_add_ui (manager, ui_id, MENU_PATH,
 			       "PageInfoSep2", NULL,
 			       GTK_UI_MANAGER_SEPARATOR, FALSE);
 
@@ -269,7 +270,7 @@ impl_attach_window (EphyExtension *extension,
 	tabs = ephy_window_get_tabs (window);
 	for (l = tabs; l != NULL; l = l->next)
 	{
-		tab_added_cb (notebook, l->data, window);
+		tab_added_cb (notebook, (EphyTab *) l->data, window);
 	}
 	g_list_free (tabs);
 
@@ -290,7 +291,7 @@ impl_detach_window (EphyExtension *extension,
 	GtkWidget *notebook;
 	GList *tabs, *l;
 
-	manager = GTK_UI_MANAGER (window->ui_merge);
+	manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 
 	data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
 	g_return_if_fail (data != NULL);
@@ -312,7 +313,7 @@ impl_detach_window (EphyExtension *extension,
 	tabs = ephy_window_get_tabs (window);
 	for (l = tabs; l != NULL; l = l->next)
 	{
-		tab_removed_cb (notebook, l->data, window);
+		tab_removed_cb (notebook, (EphyTab *) l->data, window);
 	}
 	g_list_free (tabs);
 }
