@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: Sidebar.cpp,v 1.2 2004/10/08 20:51:34 crispin Exp $
+ * $Id: Sidebar.cpp,v 1.3 2004/11/15 15:07:37 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -32,7 +32,9 @@
 #include <nsCRT.h>
 #include <nsIDOMWindowInternal.h>
 #include <nsIProgrammingLanguage.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 
 #include <glib.h>
 
