@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: register-component.cpp,v 1.1 2004/09/27 16:58:21 chpe Exp $
+ *  $Id: register-component.cpp,v 1.2 2004/11/25 20:48:21 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -32,7 +32,7 @@
 #include <nsIComponentManager.h>
 #include <nsIComponentRegistrar.h>
 #include <nsICategoryManager.h>
-#include <nsIServiceManagerUtils.h>
+#include <nsIServiceManager.h>
 #include <nsCOMPtr.h>
 #include <nsXPCOM.h>
 
