@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c,v 1.1 2004/09/08 12:39:12 chpe Exp $
+ *  $Id: smart-bookmarks-extension.c,v 1.6 2004/10/18 12:56:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,6 +45,8 @@
 
 #include <glib/gi18n-lib.h>
 
+#include <string.h>
+
 #define SMART_BOOKMARKS_EXTENSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), TYPE_SMART_BOOKMARKS_EXTENSION, SmartBookmarksExtensionPrivate))
 
 #define SMB_ACTION		"SmbExt%x"
@@ -131,7 +133,6 @@ search_gnome_dict_cb (GtkAction *action,
 		      EphyWindow *window)
 {
 	EphyEmbed *embed;
-	char *text;
 	char *argv[3] = { "gnome-dictionary", NULL, NULL };
 	GError *error = NULL;
 
@@ -222,7 +223,7 @@ context_menu_cb (EphyEmbed *embed,
 	WindowData *data;
 
 	data = (WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
-	g_return_if_fail (data != NULL);
+	g_return_val_if_fail (data != NULL, FALSE);
 
 	/* Is there some selection? */
 	can_copy = ephy_command_manager_can_do_command
@@ -302,9 +303,15 @@ rebuild_ui (WindowData *data)
 	data->ui_id = ui_id = gtk_ui_manager_new_merge_id (manager);
 
 	/* Add prefs UI */
+	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
+			       "ToolsSmartBookmarksSep1", NULL,
+			       GTK_UI_MANAGER_SEPARATOR, FALSE);
 	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
 			       "SmartBookmarksPrefsItem", "SmartBookmarksPrefs",
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
+			       "ToolsSmartBookmarksSep2", NULL,
+			       GTK_UI_MANAGER_SEPARATOR, FALSE);
 
 	/* Add bookmarks to popup context (normal document) */
 	gtk_ui_manager_add_ui (manager, ui_id, "/EphyDocumentPopup",
@@ -526,7 +533,7 @@ tab_added_cb (GtkWidget *notebook,
 }
 
 static void
-tab_removed_cb (EphyEmbed *notebook,
+tab_removed_cb (GtkWidget *notebook,
 		EphyTab *tab,
 		EphyWindow *window)
 {
@@ -575,6 +582,7 @@ impl_attach_window (EphyExtension *ext,
 	EphyBookmarks *bookmarks;
 	GPtrArray *children;
 	EphyNode *smart_bmks, *bmk;
+	GList *tabs, *l;
 	int i;
 
 	LOG ("SmartBookmarksExtension attach_window %p", window)
@@ -597,7 +605,7 @@ impl_attach_window (EphyExtension *ext,
 	gtk_action_group_add_actions (action_group, action_entries,
 				      n_action_entries, window);
 
-	data->manager = GTK_UI_MANAGER (window->ui_merge);
+	data->manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 	data->action_group = action_group;
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
@@ -612,9 +620,17 @@ impl_attach_window (EphyExtension *ext,
 	}
 
 	/* Action group completed */
-	gtk_ui_manager_insert_action_group (data->manager, action_group, 0),
+	gtk_ui_manager_insert_action_group (data->manager, action_group, -1),
 	g_object_unref (action_group);
-	
+
+	/* Sync open tabs */
+	tabs = ephy_window_get_tabs (window);
+	for (l = tabs; l != NULL; l = l->next)
+	{
+		tab_added_cb (notebook, (EphyTab *) l->data, window);
+	}
+	g_list_free (tabs);
+
 	/* now add the UI to the window */
 	rebuild_ui (data);
 }
@@ -624,15 +640,33 @@ impl_detach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 	GtkWidget *notebook;
+	GList *tabs, *l;
+	WindowData *data;
 
 	LOG ("SmartBookmarksExtension detach_window")
 
+	data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
+	g_return_if_fail (data != NULL);
+
+	gtk_ui_manager_remove_ui (data->manager, data->ui_id);
+	gtk_ui_manager_ensure_update (data->manager);
+	gtk_ui_manager_remove_action_group (data->manager, data->action_group);
+
 	notebook = ephy_window_get_notebook (window);
 
 	g_signal_handlers_disconnect_by_func
 		(notebook, G_CALLBACK (tab_added_cb), window);
 	g_signal_handlers_disconnect_by_func
 		(notebook, G_CALLBACK (tab_removed_cb), window);
+
+	tabs = ephy_window_get_tabs (window);
+	for (l = tabs; l != NULL; l = l->next)
+	{
+		tab_removed_cb (notebook, (EphyTab *) l->data, window);
+	}
+	g_list_free (tabs);
+
+	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
 }
 
 static void
@@ -677,7 +711,7 @@ smart_bookmarks_extension_init (SmartBookmarksExtension *extension)
 static void
 smart_bookmarks_extension_finalize (GObject *object)
 {
-	SmartBookmarksExtension *extension = SMART_BOOKMARKS_EXTENSION (object);
+//	SmartBookmarksExtension *extension = SMART_BOOKMARKS_EXTENSION (object);
 
 	LOG ("SmartBookmarksExtension finalising")
 
